@@ -310,7 +310,7 @@ check_args <- function(argss) {
 }
 
 #
-# model_code <- read_model_from_con('http://stan.googlecode.com/git/src/models/bugs_examples/vol1/dyes/dyes.stan')
+# model_code <- read_model_from_con('https://stan.googlecode.com/git/src/models/bugs_examples/vol1/dyes/dyes.stan')
 # cat(model_code)
 
 
@@ -863,7 +863,7 @@ remove_empty_pars <- function(pars, model_dims) {
   # following stan model code:
   #
   # transformed data { int n; n <- 0; }
-  # parameters { real y[n]; }
+  # parameters { array[n] real y; }
   #
   # Args:
   #   pars: a character vector of parameters names
@@ -934,7 +934,7 @@ rstancolgrey <- rgb(matrix(c(247, 247, 247, 204, 204, 204, 150, 150, 150, 82, 82
                     alpha = 100,
                     names = paste(1:4), maxColorValue = 255)
 
-# from http://colorbrewer2.org/, colorblind safe,
+# from https://colorbrewer2.org/, colorblind safe,
 # 6 different colors, diverging
 rstancolc <- rgb(matrix(c(230, 97, 1,
                           153, 142, 195,
@@ -1380,7 +1380,7 @@ legitimate_model_name <- function(name, obfuscate_name = TRUE) {
   # take advantage of tools such as ccache
 }
 
-boost_url <- function() {"http://www.boost.org/users/download/"}
+boost_url <- function() {"https://www.boost.org/users/download/"}
 
 makeconf_path <- function() {
   RMU <- Sys.getenv("R_MAKEVARS_USER")
@@ -1602,17 +1602,20 @@ parse_data <- function(cppcode) {
   # pull out object names from the data block
   objects <- gsub("^.* ([0-9A-Za-z_]+).*;.*$", "\\1",
                   cppcode[private:public])
-  
-  in_data <- grep("context__.vals_", cppcode, fixed = TRUE, value = TRUE)
-  in_data <- gsub('^.*\\("(.*)\"\\).*;$', "\\1", in_data)  
-  
-  # get them from the calling environment
-  objects <- intersect(objects, in_data)
+  # Remove model internal name _data__ suffix for stanc3 v2.30+
+  objects <- gsub("_data__$", "", objects)
+  # Remove model internal name underscores in case of Eigen::Maps
+  objects <- gsub("__$", "\\1", objects)
+  # Remove any bad regex matches that found the end of an Eigen::Map.
+  objects <- gsub("^[[:digit:]]+", "\\1", objects)
+  # Remove empty characters and trim whitespaces
+  objects <- objects[nzchar(trimws(objects))]
+
+  # Get them from the calling environment
   stuff <- list()
   for (int in seq_along(objects)) {
    stuff[[objects[int]]] <- dynGet(objects[int], inherits = FALSE, ifnotfound = NULL)
   }
-  
   for (i in seq_along(stuff)) if (is.null(stuff[[i]])) {
     if (exists(objects[i], envir = globalenv(), mode = "numeric"))
       stuff[[i]] <- get(objects[i], envir = globalenv(), mode = "numeric")
@@ -1647,19 +1650,17 @@ create_progress_html_file <- function(htmlfname, textfname) {
   cat(src2, file = htmlfname)
 }
 
-get_CXX <- function(CXX14 = TRUE) {
+get_CXX <- function(...) {
   if (.Platform$OS.type != "windows")
     return (system2(file.path(R.home(component = "bin"), "R"),
-            args = paste("CMD config", ifelse(CXX14, "CXX14", "CXX11")),
-            stdout = TRUE, stderr = FALSE))
+            args = "CMD config CXX17", stdout = TRUE, stderr = FALSE))
 
-    ls_path <- Sys.which("ls")
-    if (ls_path == "")
-        return(NULL)
+  ls_path <- Sys.which("ls")
+  if (ls_path == "") return(NULL)
 
-    install_path <- dirname(dirname(ls_path))
-    file.path(install_path,
-              paste0('mingw_', Sys.getenv('WIN')), 'bin', 'g++')
+  install_path <- dirname(dirname(ls_path))
+  file.path(install_path,
+            paste0('mingw_', Sys.getenv('WIN')), 'bin', 'g++')
 }
 
 is.sparc <- function() {
@@ -1711,4 +1712,3 @@ test_221 <- function(cppcode) {
   grepl("Code generated by Stan version 2.2", cppcode, fixed = TRUE) ||
   grepl("Code generated by Stan version 3", cppcode, fixed = TRUE)  
 }
-
