@@ -20,6 +20,11 @@ RNG <- 0
 OUT <- 0
 
 .onLoad <- function(libname, pkgname) {
+  if (requireNamespace("V8", quietly = TRUE)) {
+    assign("stanc_ctx", V8::v8(), envir = topenv())
+  } else assign("stanc_ctx", QuickJSR::JSContext$new(stack_size = 4 * 1024 * 1024), envir = topenv())
+  stanc_js <- system.file("stanc.js", package = "StanHeaders", mustWork = TRUE)
+  stanc_ctx$source(stanc_js)
   assignInMyNamespace("rstan_load_time", value = Sys.time())
   set_rstan_ggplot_defaults()
   assignInMyNamespace("RNG", value = get_rng(0))
@@ -29,14 +34,18 @@ OUT <- 0
 }
 
 .onAttach <- function(...) {
-  rstanLib <- dirname(system.file(package = "rstan"))
-  pkgdesc <- packageDescription("rstan", lib.loc = rstanLib)
-  gitrev <- substring(git_head(), 0, 12)
-  packageStartupMessage(paste("rstan (Version ", pkgdesc$Version, ", GitRev: ", gitrev, ")", sep = ""))
+  packageStartupMessage("\nrstan version ",
+                        utils::packageVersion("rstan"),
+                        " (Stan version ",
+                        stan_version(), ")\n")
   packageStartupMessage("For execution on a local, multicore CPU with excess RAM we recommend calling\n",
                         "options(mc.cores = parallel::detectCores()).\n",
                         "To avoid recompilation of unchanged Stan programs, we recommend calling\n",
-                        "rstan_options(auto_write = TRUE)")
+                        "rstan_options(auto_write = TRUE)",
+                        "\nFor within-chain threading using `reduce_sum()` or `map_rect()` Stan functions,\n",
+                        "change `threads_per_chain` option:\n",
+                        paste0("rstan_options(threads_per_chain = ",
+                               rstan_options("threads_per_chain"), ")\n"))
   if (.Platform$OS.type == "windows") {
     packageStartupMessage("Do not specify '-march=native' in 'LOCAL_CPPFLAGS' or a Makevars file")
   }
